//---------------------------------------------------------------------------
#ifndef CBWaveH
#define CBWaveH
//---------------------------------------------------------------------------
//not all of these headers are required
#include <MMSystem.hpp>
#include <Dialogs.hpp>
#include <Forms.hpp>
#include <Controls.hpp>
#include <Graphics.hpp>
#include <Classes.hpp>
#include <Messages.hpp>
#include <Windows.hpp>
#include <SysUtils.hpp>
#include <SysInit.hpp>
#include <System.hpp>
//---------------------------------------------------------------------------
//-- user supplied -----------------------------------------------------------

namespace Cbwave
{
//-- type declarations -------------------------------------------------------
//Wave object declaration
class DELPHICLASS  TWaveObject : public Classes::TPersistent
{
	typedef Classes::TPersistent inherited;
    //Private declarations
private:
	bool FModified;
	Classes::TMemoryStream* FWaveData;
	Classes::TNotifyEvent FOnChange;
	bool __fastcall GetEmpty(void);
	void __fastcall SetModified(bool Value);
    //Protected declarations
protected:
	virtual void __fastcall ReadData(Classes::TStream* Stream);
	virtual void __fastcall WriteData(Classes::TStream* Stream);
	void __fastcall Changed(System::TObject* Sender);
	virtual void __fastcall DefineProperties(Classes::TFiler* Filer);
    //Public declarations
public:
	__fastcall virtual TWaveObject(void);
	__fastcall ~TWaveObject(void);
	virtual void __fastcall Assign(Classes::TPersistent* Source);
	virtual void __fastcall LoadFromFile(const System::AnsiString Filename);
	virtual void __fastcall SaveToFile(const System::AnsiString Filename);
	void __fastcall LoadFromStream(Classes::TStream* Stream);
	void __fastcall SaveToStream(Classes::TStream* Stream);
	__property bool Empty = {read=GetEmpty, nodefault};
	__property Classes::TMemoryStream* WaveData = {read=FWaveData};
	__property bool Modified = {read=FModified, write=SetModified, nodefault};
	__property Classes::TNotifyEvent OnChange = {read=FOnChange, write=FOnChange};
};

typedef System::TMetaClass*TWaveClass;

enum TWavePlayOpt { wpoSync, wpoAsync, wpoNoDefault, wpoLoop, wpoNoStop , wpoNoWait, wpoPurge};

enum TWaveSource { waveMemory, waveFile, waveResource, waveAlias };

typedef Set<TWavePlayOpt, wpoSync, wpoPurge>  TOptionsSet;
//TWaveFile
class DELPHICLASS TWaveFile :public Classes::TPersistent
{
 public:
 AnsiString File;
};
// TCBWavePlayer 
class DELPHICLASS TCBWavePlayer: public Classes::TComponent 
{
  typedef Classes::TComponent inherited;
  //Private declarations
  private:
	bool FEnabled;
	TOptionsSet FOptions;
	TWaveSource Source;
    AnsiString  WaveID;
    bool ChangeCursor;
    TCursor PlayngCursor;
	TWaveObject* FWave;
	Classes::TNotifyEvent FBeforePlay;
	Classes::TNotifyEvent FAfterPlay;
	void __fastcall SetWave(TWaveObject* AWave);
	void __fastcall SetBeforePlay(Classes::TNotifyEvent Value);
	void __fastcall SetAfterPlay(Classes::TNotifyEvent Value);
  //Public declarations
  public:
	__fastcall virtual TCBWavePlayer(Classes::TComponent* AOwner);
	__fastcall virtual ~TCBWavePlayer(void);
	void __fastcall Abort(void);
	void __fastcall Play(void);
    void __fastcall FreeWave(void);
   DWORD __fastcall Flag(void);
  //Published declarations
  __published:
	__property TOptionsSet Options = {read=FOptions, write=FOptions, default=1};
	__property TWaveObject* Wave = {read=FWave, write=SetWave};
	__property Classes::TNotifyEvent BeforePlay = {read=FBeforePlay, write=SetBeforePlay};
	__property Classes::TNotifyEvent AfterPlay = {read=FAfterPlay, write=SetAfterPlay};
	__property bool Enabled = {read=FEnabled, write=FEnabled, nodefault};
    __property TWaveSource WaveSource ={read=Source, write=Source, default=waveMemory};
    __property AnsiString  WaveResource ={read=WaveID, write=WaveID, stored=true};
    __property bool DontChangeCursor  ={read=ChangeCursor, write=ChangeCursor, default=true};
    __property TCursor Cursor ={read=PlayngCursor, write=PlayngCursor, default=crHourGlass};
};

extern PACKAGE void __fastcall Register(void);

}	/* namespace CBWave */
#if !defined(NO_IMPLICIT_NAMESPACE_USE)
using namespace Cbwave;
#endif
//-- end unit ----------------------------------------------------------------
#endif // CBWave
//-- Designer ----------------------------------------------------------------
#ifndef WaveditHPP
#define WaveditHPP
#include "WaveObjectForm.h"
#include <DsgnIntf.hpp>
//-- user supplied -----------------------------------------------------------

namespace Wavedit
{
//-- type declarations -------------------------------------------------------
class DELPHICLASS TWaveEditor : public Dsgnintf::TClassProperty 
{
	typedef Dsgnintf::TClassProperty inherited;
	
public:
	virtual Dsgnintf::TPropertyAttributes __fastcall GetAttributes(void);
    virtual System::AnsiString            __fastcall GetValue();
	virtual void __fastcall Edit(void);
public:
	/* TPropertyEditor.Destroy */ 
    __fastcall virtual ~TWaveEditor(void) { }
	
public:
	/* TObject.Create */ 
    __fastcall TWaveEditor(void) : Dsgnintf::TClassProperty() { }
	
};
}	/* namespace Wavedit */
#if !defined(NO_IMPLICIT_NAMESPACE_USE)
using namespace Wavedit;
#endif
//-- end unit ----------------------------------------------------------------
#endif	// Wavedit
//============================================================================
//-- Designer ----------------------------------------------------------------
#ifndef WaveComponentHPP
#define WaveComponentHPP
#include <DsgnIntf.hpp>
//-- user supplied -----------------------------------------------------------
namespace WaveComponent
{
//-- type declarations -------------------------------------------------------
class DELPHICLASS TWaveResourceEditor : public Dsgnintf::TComponentEditor 
{
	typedef Dsgnintf::TComponentEditor inherited;
	
public:
   virtual void __fastcall Edit(void);	
};
}	/* namespace Wavedit */
#if !defined(NO_IMPLICIT_NAMESPACE_USE)
using namespace WaveComponent;
#endif
//-- end unit ----------------------------------------------------------------
#endif	// WWaveComponent
